@@ -36,7 +36,7 @@ class Object:
     def _register_grid(
         self, grid: Grid, x: ListOrSlice, y: ListOrSlice, z: ListOrSlice
     ):
-        """ Register the object to the grid
+        """Register the object to the grid
 
         Args:
             grid: the grid to register the object into
@@ -110,7 +110,7 @@ class Object:
         raise ValueError("Invalid grid indexing used for object")
 
     def update_E(self, curl_H):
-        """ custom update equations for inside the object
+        """custom update equations for inside the object
 
         Args:
             curl_H: the curl of magnetic field in the grid.
@@ -122,7 +122,7 @@ class Object:
         )
 
     def update_H(self, curl_E):
-        """ custom update equations for inside the object
+        """custom update equations for inside the object
 
         Args:
             curl_E: the curl of electric field in the grid.
@@ -171,7 +171,7 @@ class AbsorbingObject(Object):
     def _register_grid(
         self, grid: Grid, x: slice = None, y: slice = None, z: slice = None
     ):
-        """ Register a grid to the object
+        """Register a grid to the object
 
         Args:
             grid: the grid to register the object into
@@ -180,6 +180,14 @@ class AbsorbingObject(Object):
             z: the z-location of the object in the grid
         """
         super()._register_grid(grid=grid, x=x, y=y, z=z)
+
+        conductivity = bd.asarray(self.conductivity)
+        while conductivity.ndim < self.inverse_permittivity.ndim:
+            conductivity = conductivity[..., None]
+        self.conductivity = bd.broadcast_to(
+            conductivity, self.inverse_permittivity.shape
+        )
+
         self.absorption_factor = (
             0.5
             * self.grid.courant_number
@@ -190,7 +198,7 @@ class AbsorbingObject(Object):
         )
 
     def update_E(self, curl_H):
-        """ custom update equations for inside the absorbing object
+        """custom update equations for inside the absorbing object
 
         Args:
             curl_H: the curl of magnetic field in the grid.
@@ -206,7 +214,7 @@ class AbsorbingObject(Object):
         )
 
     def update_H(self, curl_E):
-        """ custom update equations for inside the absorbing object
+        """custom update equations for inside the absorbing object
 
         Args:
             curl_E: the curl of electric field in the grid.
@@ -220,7 +228,7 @@ class AnisotropicObject(Object):
     def _register_grid(
         self, grid: Grid, x: slice = None, y: slice = None, z: slice = None
     ):
-        """ Register a grid to the object
+        """Register a grid to the object
 
         Args:
             grid: the grid to register the object into
@@ -237,7 +245,7 @@ class AnisotropicObject(Object):
         )
 
     def update_E(self, curl_H):
-        """ custom update equations for inside the anisotropic object
+        """custom update equations for inside the anisotropic object
 
         Args:
             curl_H: the curl of magnetic field in the grid.
@@ -254,7 +262,7 @@ class AnisotropicObject(Object):
         )
 
     def update_H(self, curl_E):
-        """ custom update equations for inside the anisotropic object
+        """custom update equations for inside the anisotropic object
 
         Args:
             curl_E: the curl of electric field in the grid.
